﻿<?xml version="1.0" encoding="UTF-8"?>

<!-- Generates a SQL DDL from the XML output of the Orthogonal Toolbox			-->
<!-- Orthogonal Toolbox is a free utility produced by Orthogonal Software Corporation	-->
<!-- http://www.orthogonalsoftware.com												-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" version="1.0" encoding="UTF-8" indent="no"/>
	<xsl:template match="/">
	<html>
	<head>
	<title>xml</title>
	</head>
	<body>
		<xsl:apply-templates/>
	</body>
	</html>
	</xsl:template>
	
	<xsl:template match="LogicalModels">
		<xsl:for-each select="LogicalModel">/* DDL generated from <xsl:value-of select="@FileName"/> last saved on <xsl:value-of select="@FileSavedOn"/> */
<p />
<xsl:apply-templates select="Entities/Entity[@IsView='false']" mode="table"/>
<xsl:apply-templates select="Relationships/Relationship" mode="fk"/>
</xsl:for-each>
</xsl:template>
	
	<xsl:template match="Entity" mode="table">
CREATE TABLE <xsl:value-of select="@PhysicalName"/>
(
	<br />
	<xsl:for-each select="EntityAttributes/EntityAttribute">
		<span style="padding-left: 20px;">
		<xsl:apply-templates select="../../../../Attributes/Attribute[@AttributeID = current()/@EntityAttributeID]" mode="table"/>
		</span>
		<xsl:if test="count(../../EntityAttributes/EntityAttribute) != position()">,</xsl:if>
		<br />
	</xsl:for-each>
);
<br />
GO
<p />

<xsl:apply-templates select="EntityAnnotations/EntityAnnotation[@AnnotationType='Primary Key']" mode="pk"/>
<xsl:apply-templates select="EntityAnnotations/EntityAnnotation[@AnnotationType='Alternate Key']" mode="ak"/>
<xsl:apply-templates select="EntityAnnotations/EntityAnnotation[@AnnotationType='Index']" mode="idx"/>
</xsl:template>

	<!-- Create column for each EntityAttribute -->
	<xsl:template match="Attribute" mode="table">
		<xsl:variable name="nullability">
			<xsl:choose>
				<xsl:when test='@AllowNulls = "false"'> NOT NULL</xsl:when>
				<xsl:otherwise> NULL</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	[<xsl:value-of select="@PhysicalName"/>] <span style="text-transform:uppercase;"><xsl:value-of select="@PhysicalDatatype"/></span>  <xsl:value-of select="$nullability"/>
		
</xsl:template>

<xsl:template match="EntityAnnotation" mode="pk">
	
	ALTER TABLE <xsl:value-of select="../../@PhysicalName"/>
		<br />
		<span style="padding-left: 20px;">
		ADD CONSTRAINT [<xsl:value-of select="@ConstraintName"/>] 
		</span>
		<br />
		<span style="padding-left: 20px;">
		PRIMARY KEY (<xsl:for-each select="EntityAnnotationAttributes/EntityAnnotationAttribute">[<xsl:value-of select="../../../../../../Attributes/Attribute[@AttributeID = current()/@EntityAnnotationAttributeID]/@PhysicalName"/>]<xsl:if test="count(../../EntityAnnotationAttributes/EntityAnnotationAttribute) != position()">, </xsl:if></xsl:for-each>);
		</span>
	<br />
	GO
	<p />
</xsl:template>

	<xsl:template match="EntityAnnotation" mode="ak">
CREATE UNIQUE INDEX [<xsl:value-of select="@ConstraintName"/>] on <xsl:value-of select="../../@PhysicalName"/> (<xsl:for-each select="EntityAnnotationAttributes/EntityAnnotationAttribute">[<xsl:value-of select="../../../../../../Attributes/Attribute[@AttributeID = current()/@EntityAnnotationAttributeID]/@PhysicalName"/>]<xsl:if test="count(../../EntityAnnotationAttributes/EntityAnnotationAttribute) != position()">, </xsl:if></xsl:for-each>);
<br />
GO
<p />

</xsl:template>

	<xsl:template match="EntityAnnotation" mode="idx">
CREATE INDEX [<xsl:value-of select="@ConstraintName"/>] on <xsl:value-of select="../../@PhysicalName"/> (<xsl:for-each select="EntityAnnotationAttributes/EntityAnnotationAttribute">[<xsl:value-of select="../../../../../../Attributes/Attribute[@AttributeID = current()/@EntityAnnotationAttributeID]/@PhysicalName"/>]<xsl:if test="count(../../EntityAnnotationAttributes/EntityAnnotationAttribute) != position()">, </xsl:if></xsl:for-each>);
<br />
GO
<p />

</xsl:template>

	<xsl:template match="Relationship" mode="fk">
	<xsl:variable name="ri">
		<xsl:choose>
			<xsl:when test='@UpdateRule="No Action"'>ON UPDATE NO ACTION </xsl:when>
			<xsl:when test='@UpdateRule="Cascade"'>ON UPDATE CASCADE </xsl:when>
			<xsl:when test='@UpdateRule="Set Null"'></xsl:when>
			<xsl:when test='@UpdateRule="Set Default"'></xsl:when>
			<xsl:when test='@UpdateRule="Do Not Enforce"'></xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test='@DeleteRule="No Action"'>ON DELETE NO ACTION</xsl:when>
			<xsl:when test='@DeleteRule="Cascade"'>ON DELETE CASCADE</xsl:when>
			<xsl:when test='@DeleteRule="Set Null"'></xsl:when>
			<xsl:when test='@DeleteRule="Set Default"'></xsl:when>
			<xsl:when test='@DeleteRule="Do Not Enforce"'></xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="disable_ri">
		<xsl:choose>
			<xsl:when test='@UpdateRule="Set Null" or @UpdateRule="Set Default" or @UpdateRule="Do Not Enforce" or @DeleteRule="Set Null" or @DeleteRule="Set Default" or @DeleteRule="Do Not Enforce"'>
<br />
GO
<p />

		ALTER TABLE <xsl:value-of select="../../Entities/Entity[@EntityID = current()/@FirstEntityID]/@PhysicalName"/> NOCHECK CONSTRAINT [<xsl:value-of select="@PhysicalName"/>]</xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	ALTER TABLE <xsl:value-of select="../../Entities/Entity[@EntityID = current()/@FirstEntityID]/@PhysicalName"/> 
		<br />
		<span style="padding-left: 20px;">
		ADD CONSTRAINT [<xsl:value-of select="@PhysicalName"/>] 
		</span>
		<br />
		<span style="padding-left: 20px;">
		FOREIGN KEY (<xsl:for-each select="FirstAttributes/FirstAttribute">[<xsl:value-of select="../../../../Attributes/Attribute[@AttributeID = current()/@FirstAttributeID]/@PhysicalName"/>]<xsl:if test="count(../../FirstAttributes/FirstAttribute) != position()">, </xsl:if></xsl:for-each>)
		</span>
		<br />
		<span style="padding-left: 20px;">
		REFERENCES <xsl:value-of select="../../Entities/Entity[@EntityID = current()/@SecondEntityID]/@PhysicalName"/> (<xsl:for-each select="SecondAttributes/SecondAttribute">[<xsl:value-of select="../../../../Attributes/Attribute[@AttributeID = current()/@SecondAttributeID]/@PhysicalName"/>]<xsl:if test="count(../../SecondAttributes/SecondAttribute) != position()">, </xsl:if></xsl:for-each>) 
		</span>
	<xsl:value-of select="$ri"/><xsl:value-of select="$disable_ri"/>
<br />
GO
<p />
</xsl:template>
	
</xsl:stylesheet>
<!-- © 2004 Orthogonal Software Corporation. All rights reserved. -->
